<?php

namespace Teknisa\SM\Controller;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Teknisa\SM\Service\SmRelatorioContratoDataSourceService;
use Teknisa\Libs\Util\Environment;

class SmRelatorioContratoDataSourceController {
    protected $environment;
    protected $relatorioService;
    
    public function __construct(SmRelatorioContratoDataSourceService $relatorioService, Environment $environment) {
        $this->relatorioService = $relatorioService;
        $this->environment      = $environment;
    }
   /**
    * A função "find" Busca os dados para a tela sem ou com filtro
    */
    public function find(Request\Filter $request, Response $response) {
        try {
            $filterData = $request->getFilterCriteria();
            $filtros    = $this-> getFilters($filterData);
            $cdoperador = $this->environment->getCdOperador();
            $nrorg      = $this->environment->getNrorg();
            $page       = $request->getParameters()["page"];
            
            $resultados = $this->relatorioService->find($filtros, $page, $cdoperador, $nrorg);
            $response->addDataSet(new DataSet('fct_contrato_relatorio_widget', $resultados));
        }
        catch (\Exception $e) {
            $response->setError(new Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    /**
    * A função "find" Busca os dados para a tela sem ou com filtro
    */
    public function findItens(Request\Filter $request, Response $response) {
        $filterData = $request->getFilterCriteria();
        $filtros    = $this-> getFilters($filterData);
        $cdoperador = $this->environment->getCdOperador();
        $nrorg      = $this->environment->getNrorg();
        //$page       = $request->getParameters()["page"];
        
        $resultados = $this->relatorioService->findItens($filtros, $cdoperador, $nrorg);
        $response->addDataSet(new DataSet('fct_itemcontrato_relatorio_widget', $resultados));
    }
    /**
     * Retorna os filtros da tela
    **/
    public function getFilters($filterData) {
        $filtros = array();
        if (count($filterData->getConditions()) > 0) {
            $camposStr  = array("CDOPERRESPONSAVEL", "IDELEMENTO", "IDSITUACAOCONTRATO", "CDCENTCUST", "CDFILIALORCA");
            $camposDate = array("DTINICIOCONTRATO", "DTFIMCONTRATO", "DTINICONTRATO", "DTFINCONTRATO", "DTRECISAOCONTR");
            foreach ($filterData->getConditions() as $filter) { 
                $value = $filter["value"];
                if(is_array($filter["value"]) && !in_array($filter["columnName"], $camposDate)) {
                    $isCampoStr = (in_array($filter["columnName"], $camposStr));
                    $value  = implode(($isCampoStr ? "','" : ","), $filter["value"]);
                }
                
                $filtros[$filter["columnName"]] = $value;
            }
        }
        return $filtros;
    }
}
?>

