<?php
namespace Teknisa\SM\Service;

use Teknisa\SM\Factory\Sm00009000ParamFaturaModeloContratoFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;

class Sm00009000ParamFaturaModeloContratoService
{
    
    protected $ParamFaturaModContratoFactory;
    protected $Environment;
    protected $newCode;
    
    public function __construct (Sm00009000ParamFaturaModeloContratoFactory $ParamFaturaModContratoFactory, Environment $Environment, NewCode $newCode){
        
        $this->ParamFaturaModContratoFactory  = $ParamFaturaModContratoFactory;
        $this->Environment  = $Environment;
        $this->newCode  = $newCode;

    }
    
    /**
     * A função "insereDadosModContrato" insere os dados de parametização 
     * de fatiuramento na tabela de Modelo de Contrato (FCT_MODELOCONTRATO).
     */
     
    public function insereDadosModContrato($dtInicFatContr, $idQtDiasCompCon, $nrQtDiasCompCon, $idCompetCont, $nrDiaCompetCont, $idTpDtEmissNf, $nrDiaDtEmissNf, $idTpDtVenc, $nrDiaVenParcFat, $idTpFatuIncomp, $seqModContrato){
    
        $paramsInsereDadosModContr = array(
            
            "DTINICFATCONTR" =>  $dtInicFatContr,
            "IDQTDIASCOMPCON" =>  $idQtDiasCompCon,
            "NRQTDIASCOMPCON" => $nrQtDiasCompCon,
            "IDTPCOMPETCONT" => $idCompetCont,
            "NRDIACOMPETCONT" => $nrDiaCompetCont,
            "IDTPDTEMISSNF" => $idTpDtEmissNf,
            "NRDIADTEMISSNF" => $nrDiaDtEmissNf,
            "IDTPDTVENC" =>  $idTpDtVenc,
            "NRDIAVENPARCFAT" => $nrDiaVenParcFat,
            "IDTPFATUINCOMP" => $idTpFatuIncomp,
            "NRSEQMODCONTRA" => $seqModContrato,
            "NRORG"  => $this->Environment->getNrOrg()
        );
        
      $this->ParamFaturaModContratoFactory->insereDadosModContrato($paramsInsereDadosModContr);
        
        
    }
    public function procuraPerfilParametrizado($nrorg, $nrmodelo, $isproporcont){

      if($isproporcont == "C"){
          $params = array(
              "NRSEQMODCONTRA" => $nrmodelo,
              "NRORG"          => $nrorg
          );
          $result = $this->ParamFaturaModContratoFactory->procuraPerfilContrato($params);
      }
      if($isproporcont == "P"){
          $params = array(
              "NRORCAMENTOMODELO" => $nrmodelo,
              "NRORG"          => $nrorg
          );
          $result = $this->ParamFaturaModContratoFactory->procuraPerfilProposta($params);
      }
        foreach($result as $count=>$r){
            $perfil[$count] = $r["NRPERFILACESSO"];
        }

        if(!$result){
            return array();
        }
        return $perfil;
    }
    
    /**
     * insere os signatários padrões de modelo de contrato que foram buscados na parametrização SM 
    **/
    public function insereSignatariosPadroesContr($row, $nrorg, $operador){
        try {
            
            $params = array(
                "NRORG" => $nrorg
            );
            
            $certsign = $this->ParamFaturaModContratoFactory->validaTokenCertsign($params);
            
            if(count($certsign) > 0) {
                
                $params = array(
                    "NRORG" => $nrorg
                );
                
                $signatarios = $this->ParamFaturaModContratoFactory->buscaSignatariosPadroes($params);
                
                if(count($signatarios) > 0) {
                
                  foreach($signatarios as $signatario){
                      
                      $params = array(
                          "NRSEQMODCONTRA" => $row["NRSEQMODCONTRA"],
                          "NRPARCNEGOCIO"  => $signatario["NRPARCNEGOCIO"],
                          "NRORG"          => $nrorg
                      );
                      
                      $valida = $this->ParamFaturaModContratoFactory->validaSignatCadastrados($params);
                      
                      if ($valida == 0){
                      
                          $nrsignatpadrcont = $this->newCode->getCodeByTableName("FCT_SIGNATPADRMODCONT", $nrorg, 1, 10, true);
                          
                          $params= array(
                              "NRSIGNATPADRCONT"  => $nrsignatpadrcont,
                              "NRSEQMODCONTRA"    => $row["NRSEQMODCONTRA"],
                              "NRPARCNEGOCIO"     => $signatario["NRPARCNEGOCIO"], 
                              "IDTIPOASSINATURA"  => $signatario["IDTIPOASSINATURA"], 
                              "IDTESTEMUNHA"      => $signatario["IDTESTEMUNHA"], 
                              "NRORDENACAO"       => $signatario["NRORDENACAO"], 
                              "NRORG"             => $nrorg,  
                              "OPERADOR"          => $operador
                          );
                          
                          $signatarios = $this->ParamFaturaModContratoFactory->insereSignatariosPadroes($params);
                      } 
                  }  
                }
            }
        } catch(\Exception $e) {
            throw $e;
        }
    }

    /**
     * A função "cadAutoSignatPadrCont" realiza o cadastramento automático dos signatários padrões do modelo de contrato
     */
    public function cadAutoSignatPadrCont($row){
        try {
            
            $nrorg = $this->Environment->getNrOrg();
            $operador = $this->Environment->getCdOperador();
            
            $params = array(
                "NRORG" => $nrorg
            );
            
            $certsign = $this->ParamFaturaModContratoFactory->validaTokenCertsign($params);
            
            if(count($certsign) > 0) {
                
                $nrseqmodcontra   = $row["NRSEQMODCONTRA"];
                $idtipoassinatura = $row["IDTIPOASSINATURA"]; 
                $idtestemunha     = $row["IDTESTEMUNHA"];
                $nrordenacao      = $row["NRORDENACAO"];
                $signatarios      = $row["NRPARCNEGOCIO"];
                
                if(count($nrseqmodcontra) > 0) {
                
                   foreach($nrseqmodcontra as $modelo) {
                
                        if(count($signatarios) > 0) {
                        
                           foreach($signatarios as $signatario){
                              
                              $params = array(
                                  "NRSEQMODCONTRA" => $modelo,
                                  "NRPARCNEGOCIO"  => $signatario,
                                  "NRORG"          => $nrorg
                              );
                              
                              $valida = $this->ParamFaturaModContratoFactory->validaSignatCadastrados($params);
                              
                              if ($valida == 0){
                              
                                  $nrsignatpadrcont = $this->newCode->getCodeByTableName("FCT_SIGNATPADRMODCONT", $nrorg, 1, 10, true);
                                  
                                  $params= array(
                                      "NRSIGNATPADRCONT" => $nrsignatpadrcont,
                                      "NRSEQMODCONTRA"   => $modelo,
                                      "NRPARCNEGOCIO"    => $signatario, 
                                      "IDTIPOASSINATURA" => $idtipoassinatura, 
                                      "IDTESTEMUNHA"     => $idtestemunha, 
                                      "NRORDENACAO"      => $nrordenacao, 
                                      "NRORG"            => $nrorg,  
                                      "OPERADOR"         => $operador
                                  );
                                  
                                  $this->ParamFaturaModContratoFactory->insereSignatariosPadroes($params);
                              }
                           }  
                        }
                    }
                }
            }
            
            $retorno = 'OK';
            
        } catch(\Exception $e) {
            $retorno = $e->getMessage();
            //throw $e;
        }
        
         return $retorno;
    }
    
    /**
     * A função "validaSignatPadrCont" realiza a validação dos signatários padrões para evitar a inclusão repetida de um parceiro.
     */
    public function validaSignatPadrCont($row){
        try {
            
           $nrorg = $this->Environment->getNrOrg();
           $nrparcnegocio = $row["NRPARCNEGOCIO"];
           $nrseqmodcontra = $row["NRSEQMODCONTRA"];
           
           $params = array(
              "NRSEQMODCONTRA" => $nrseqmodcontra,
              "NRPARCNEGOCIO"  => $nrparcnegocio,
              "NRORG"          => $nrorg
           );
          
           $valida = $this->ParamFaturaModContratoFactory->validaSignatCadastrados($params);
        
           return $valida;    
        
        } catch(\Exception $e) {
            throw $e;
        }   
    }
    
    /**
     * Valida se o token da certsign está preenchido
     */
    public function validaIdCertsign($nrorg){
        try {
            
           $params = array(
                "NRORG" => $nrorg
           );
            
           $certsign = $this->ParamFaturaModContratoFactory->validaTokenCertsign($params);
        
           $certsign = $certsign[0]["DSTOKENCERTSIGN"];   
           
           return $certsign;    
        
        } catch(\Exception $e) {
            throw $e;
        }   
    }
}
?>